summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--NEWS2
-rw-r--r--SConstruct14
-rw-r--r--build.txt2
-rw-r--r--doc/explan_ntpshm.c.xml2
-rw-r--r--doc/internals.xml4
-rw-r--r--ntpmon.xml12
-rw-r--r--ntpshmmon.c (renamed from ntpmon.c)12
-rw-r--r--ntpshmread.c2
-rw-r--r--ntpshmwrite.c (renamed from ntpshm.c)4
-rw-r--r--www/index.html.in2
10 files changed, 28 insertions, 28 deletions
diff --git a/NEWS b/NEWS
index f7edce5e..60ec9e1c 100644
--- a/NEWS
+++ b/NEWS
@@ -3,7 +3,7 @@
3.13: 2015-02-26 (Eric S. Raymond <esr@snark.thyrsus.com>)
compiler.h inclusion removed for gps.h so it's standalone for /usr/include.
TOFF JSON report gives the offset between GPS top of second and clock time.
- A new ntpmon tool supports capturing clock samples from NTP SHM segments.
+ A new ntpshmmon tool supports capturing clock samples from NTP SHM segments.
3.12: 2015-02-22 (Eric S. Raymond <esr@snark.thyrsus.com>)
The daemon's power utilization has been reduced by changing from
diff --git a/SConstruct b/SConstruct
index 79305a3e..372c617d 100644
--- a/SConstruct
+++ b/SConstruct
@@ -1027,7 +1027,7 @@ gpsdlibs = ["-lgpsd"] + usblibs + bluezlibs + gpslibs
# Source groups
-gpsd_sources = ['gpsd.c','ntpshm.c','shmexport.c','dbusexport.c']
+gpsd_sources = ['gpsd.c','ntpshmwrite.c','shmexport.c','dbusexport.c']
if env['systemd']:
gpsd_sources.append("sd_socket.c")
@@ -1079,10 +1079,10 @@ env.Depends(lcdgps, compiled_gpslib)
cgps = env.Program('cgps', ['cgps.c'], parse_flags=gpslibs + ncurseslibs)
env.Depends(cgps, compiled_gpslib)
-ntpmon = env.Program('ntpmon', ['ntpmon.c'], parse_flags=gpslibs)
+ntpshmmon = env.Program('ntpshmmon', ['ntpshmmon.c'], parse_flags=gpslibs)
env.Depends(cgps, compiled_gpslib)
-binaries = [gpsd, gpsdecode, gpsctl, gpsdctl, gpspipe, gps2udp, gpxlogger, lcdgps, ntpmon]
+binaries = [gpsd, gpsdecode, gpsctl, gpsdctl, gpspipe, gps2udp, gpxlogger, lcdgps, ntpshmmon]
if env["ncurses"]:
binaries += [cgps, gpsmon]
@@ -1337,7 +1337,7 @@ base_manpages = {
"gps2udp.1" : "gps2udp.xml",
"gpsdecode.1" : "gpsdecode.xml",
"srec.5" : "srec.xml",
- "ntpmon.1" : "ntpmon.xml",
+ "ntpshmmon.1" : "ntpshmmon.xml",
}
python_manpages = {
"gpsprof.1" : "gpsprof.xml",
@@ -1380,7 +1380,7 @@ headerinstall = [ env.Install(installdir('includedir'), x) for x in ("libgpsmm.h
binaryinstall = []
binaryinstall.append(env.Install(installdir('sbindir'), [gpsd, gpsdctl]))
binaryinstall.append(env.Install(installdir('bindir'), [gpsdecode, gpsctl, gpspipe, gps2udp,
- gpxlogger, lcdgps, ntpmon]))
+ gpxlogger, lcdgps, ntpshmmon]))
if env["ncurses"]:
binaryinstall.append(env.Install(installdir('bindir'), [cgps, gpsmon]))
binaryinstall.append(LibraryInstall(env, installdir('libdir'), compiled_gpslib))
@@ -1491,7 +1491,7 @@ splint_table = [
('splint-gps2udp',['gps2udp.c'],'gps2udp', ['']),
('splint-gpsdecode',['gpsdecode.c'],'gpsdecode', ['']),
('splint-gpxlogger',['gpxlogger.c'],'gpxlogger', ['']),
- ('splint-ntpmon',['ntpmon.c'],'ntpmon', ['']),
+ ('splint-ntpshmmon',['ntpshmmon.c'],'ntpshmmon', ['']),
('splint-test_packet',['test_packet.c'],'test_packet test harness', ['']),
('splint-test_mktime',['test_mktime.c'],'test_mktime test harness', ['']),
('splint-test_geoid',['test_geoid.c'],'test_geoid test harness', ['']),
@@ -1934,7 +1934,7 @@ distclean = env.Alias('distclean', [clean, testclean, webclean])
# Tags for Emacs and vi
misc_sources = ['cgps.c', 'gpsctl.c', 'gpsdctl.c', 'gpspipe.c',
- 'gps2udp.c', 'gpsdecode.c', 'gpxlogger.c', 'ntpmon']
+ 'gps2udp.c', 'gpsdecode.c', 'gpxlogger.c', 'ntpshmmon']
sources = libgpsd_sources + libgps_sources \
+ gpsd_sources + gpsmon_sources + misc_sources
env.Command('TAGS', sources, ['etags ' + " ".join(sources)])
diff --git a/build.txt b/build.txt
index 811b6adc..8c946972 100644
--- a/build.txt
+++ b/build.txt
@@ -66,7 +66,7 @@ move structure members in and out of unions.
Some portions of the code using shared-memory segments are improved by
the C11 stdatomic.h features for lockless concurrency. These are: the
SHM export mode in shmexport.c, the code for writing clock corrections
-to NTP in ntpshm.c, and the code for reading NTP corrections in
+to NTP in ntpshmwrite.c, and the code for reading NTP corrections in
ntpshmread.c. These features have been supported in GCC since 4.7 and
clang since 3.1.
diff --git a/doc/explan_ntpshm.c.xml b/doc/explan_ntpshm.c.xml
index cc7fafc4..97e64012 100644
--- a/doc/explan_ntpshm.c.xml
+++ b/doc/explan_ntpshm.c.xml
@@ -1,4 +1,4 @@
-<sect1 id="ntpshm.c"><title><filename>ntpshm.c</filename></title>
+<sect1 id="ntpshmwrite.c"><title><filename>ntpshmwrite.c</filename></title>
<informaltable frame='all' pgwide='1'>
<tgroup cols='2'>
<colspec colname='c1'></colspec>
diff --git a/doc/internals.xml b/doc/internals.xml
index cf33a535..b209387c 100644
--- a/doc/internals.xml
+++ b/doc/internals.xml
@@ -24,7 +24,7 @@
<!ENTITY net_dgpsip.c SYSTEM "explan_net_dgpsip.c.xml">
<!ENTITY net_ntrip.c SYSTEM "explan_net_ntrip.c.xml">
<!ENTITY netlib.c SYSTEM "explan_netlib.c.xml">
-<!ENTITY ntpshm.c SYSTEM "explan_ntpshm.c.xml">
+<!ENTITY ntpshmwrite.c SYSTEM "explan_ntpshmwrite.c.xml">
<!ENTITY packet.c SYSTEM "explan_packet.c.xml">
<!ENTITY packet_names.h SYSTEM "explan_packet_names.h.xml">
<!ENTITY packet_states.h SYSTEM "explan_packet_states.h.xml">
@@ -105,7 +105,7 @@ is not yet documented here.</para>
&net_dgpsip.c;
&net_ntrip.c;
&netlib.c;
-&ntpshm.c;
+&ntpshmwrite.c;
&packet.c;
&packet_names.h;
&packet_states.h;
diff --git a/ntpmon.xml b/ntpmon.xml
index 7dad08ae..f9c8a1d7 100644
--- a/ntpmon.xml
+++ b/ntpmon.xml
@@ -6,22 +6,22 @@ BSD terms apply: see the file COPYING in the distribution root for details.
<!DOCTYPE refentry PUBLIC
"-//OASIS//DTD DocBook XML V4.1.2//EN"
"http://www.oasis-open.org/docbook/xml/4.1.2/docbookx.dtd">
-<refentry id='ntpmon.1'>
+<refentry id='ntpshmmon.1'>
<refentryinfo><date>25 Jan 2015</date></refentryinfo>
<refmeta>
-<refentrytitle>ntpmon</refentrytitle>
+<refentrytitle>ntpshmmon</refentrytitle>
<manvolnum>1</manvolnum>
<refmiscinfo class="source">The GPSD Project</refmiscinfo>
<refmiscinfo class="manual">GPSD Documentation</refmiscinfo>
</refmeta>
<refnamediv id='name'>
-<refname>ntpmon</refname>
+<refname>ntpshmmon</refname>
<refpurpose>capture samples from GPS or other ntpd refclock sources</refpurpose>
</refnamediv>
<refsynopsisdiv id='synopsis'>
<cmdsynopsis>
- <command>ntpmon</command>
+ <command>ntpshmmon</command>
<arg choice='opt'>-h </arg>
<arg choice='opt'>-s </arg>
<arg choice='opt'>-v </arg>
@@ -44,7 +44,7 @@ whitespace-separated textual fields.</para>
<para>Here is an example of the beginning of a report file:
<literallayout>
-ntpmon version 1
+ntpshmmon version 1
sample NTP2 1424926256.443030206 1424926256.115869233 1424926256.000000000 0 -1
sample NTP3 1424926256.443060517 1424926255.995430821 1424926256.000000000 0 -20
sample NTP3 1424926256.995747347 1424926256.995422728 1424926257.000000000 0 -20
@@ -55,7 +55,7 @@ sample NTP3 1424926258.995647636 1424926258.995406476 1424926259.000000000 0 -20
</literallayout></para>
<para>The output always begins with a header line expressing the
-version of the output format; the version line begins with "ntpmon
+version of the output format; the version line begins with "ntpshmmon
version" and is followed by a numeric version field.</para>
<para>The remainder of the file is sample lines. The fields of a
diff --git a/ntpshmread.c b/ntpshmread.c
index b1c62904..092e6e95 100644
--- a/ntpshmread.c
+++ b/ntpshmread.c
@@ -1,4 +1,4 @@
-/* ntpshmread.c -- monitor the inner end of an ntpshm connection
+/* ntpshmread.c -- monitor the inner end of an ntpshmwrite.connection
*
* This file is Copyright (c) 2010 by the GPSD project
* BSD terms apply: see the file COPYING in the distribution root for details.
diff --git a/ntpshm.c b/ntpshmwrite.c
index 0d11a089..2e160b21 100644
--- a/ntpshm.c
+++ b/ntpshmwrite.c
@@ -1,5 +1,5 @@
/*
- * ntpshm.c - put time information in SHM segment for xntpd, or to chrony
+ * ntpshmwrite.c - put time information in SHM segment for xntpd, or to chrony
*
* struct shmTime and getShmTime from file in the xntp distribution:
* sht.c - Testprogram for shared memory refclock
@@ -127,7 +127,7 @@ static /*@null@*/ volatile struct shmTime *getShmTime(struct gps_context_t *cont
/*
* Note: this call requires root under BSD, and possibly on
- * well-secured Linux systems. This is why ntpshm_context_init() has to be
+ * well-secured Linux systems. This is why ntpshmwrite.context_init() has to be
* called before privilege-dropping.
*/
shmid = shmget((key_t) (NTPD_BASE + unit),
diff --git a/www/index.html.in b/www/index.html.in
index 5f01b9d2..5014510f 100644
--- a/www/index.html.in
+++ b/www/index.html.in
@@ -306,7 +306,7 @@ protocol of the <code>gpsd</code> daemon.</dd>
<dd>Feed the take from <code>gpsd</code> to one or more aggregation
sites via UDP.</dd>
-<dt><a href="ntpmon.html">ntpmon.1</a></dt>
+<dt><a href="ntpshmmon.html">ntpshmmon.1</a></dt>
<dd>Monitor the NTP shared-memory segments created by GPSD.</dd>
</dl>
diff --git a/ntpmon.c b/ntpshmmon.c
index 7899fd77..044f9268 100644
--- a/ntpmon.c
+++ b/ntpshmmon.c
@@ -1,4 +1,4 @@
/* ntpmon.c -- monitor the inner end of an ntpshm connection
*
* This file is Copyright (c) 2010 by the GPSD project
* BSD terms apply: see the file COPYING in the distribution root for details.
@@ -35,7 +35,7 @@ int main(int argc, char **argv)
int i;
bool verbose = false;
-#define USAGE "usage: ntpmon [-s] [-v] [-h]\n"
+#define USAGE "usage: ntpshmmon [-s] [-v] [-h]\n"
while ((option = getopt(argc, argv, "hsv")) != -1) {
switch (option) {
case 's':
@@ -43,7 +43,7 @@ int main(int argc, char **argv)
shm_shutdown();
exit(EXIT_SUCCESS);
} else {
- fprintf(stderr, "ntpmon: zero units declared.\n");
+ fprintf(stderr, "ntpshmmon: zero units declared.\n");
exit(EXIT_FAILURE);
}
//0break;
@@ -63,7 +63,7 @@ int main(int argc, char **argv)
if (verbose && segments[i] != NULL)
fprintf(stderr, "unit %d opened\n", i);
}
- (void)printf("ntpmon version 1\n");
+ (void)printf("ntpshmmon version 1\n");
for (;;) {
struct shm_stat_t shm_stat;
@@ -96,7 +96,7 @@ int main(int argc, char **argv)
break;
case BAD_MODE:
/*@-mustfreefresh@*/
- fprintf(stderr, "ntpmon: unknown mode %d on segment %s\n",
+ fprintf(stderr, "ntpshmmon: unknown mode %d on segment %s\n",
shm_stat.status, shm_name(i));
/*@+mustfreefresh@*/
break;
@@ -105,7 +105,7 @@ int main(int argc, char **argv)
break;
default:
/*@-mustfreefresh@*/
- fprintf(stderr, "ntpmon: unknown status %d on segment %s\n",
+ fprintf(stderr, "ntpshmmon: unknown status %d on segment %s\n",
status, shm_name(i));
/*@+mustfreefresh@*/
break;
@@ -1,4 +1,4 @@
-/* ntpmon.c -- monitor the inner end of an ntpshm connection
+/* ntpshmmon.c -- monitor the inner end of an ntpshmwrite.connection
*
* This file is Copyright (c) 2010 by the GPSD project